/* $Id: eepromdata.h,v 1.6 2012-03-19 22:30:06 simimeie Exp $
 * Defines the contents of the EEPROM.
 * The EEPROM contains settings like password and IP adress. Theoretically,
 * you only need to reprogram the eeprom after changing values here, unless
 * compiler version changed and thus the data got reordered.
 */ 

#define EEPROM __attribute__ ((section (".eeprom")))

/* ***********************
 * Network Configuration *
 *********************** */

/* Our MAC address. This needs to be set, the enc28j60
 * does not have any "built in".
 * Unless you have a proper address area assigned, you
 * should choose a locally administered address. These
 * have bit 2 (i.e. | 0x02) set in the first byte.
 * note that bit 1 must not be set. */
uint8_t EEPROM ee_mac[6] = { 0x02, 0xaf, 0xfe, 0xbe, 0xef, 0x23 }; 

/* Enable Full Duplex.
 * Do NOT enable this unless the device is connected to a manageable
 * switch that has been configured to force 10 MBit Full Duplex on
 * the port. This is the only scenario where FDX will work with
 * 10 MBit, as there is no possible way of autodetection. */
uint8_t EEPROM ee_fdx = 0;

/* Our IPv4 address. */
uint8_t EEPROM ee_ip4[4] =   { 172,  17,   3, 164 };
#if 0
/* We will probably never need this, we would only
 * need it if we did connections ourselves, but we
 * only reply to packets sent by others, so we
 * never do any ARP requests */
uint8_t EEPROM ee_mask[4] = { 255, 255, 252,   0 };
uint8_t EEPROM ee_gate[4] = {  10, 232,   0,   1 };
#endif

/* Our IPv6 address.
 * Can be all zero if set via autoconfig... */
uint8_t EEPROM ee_ip6[16] = { 0x00, 0x00, 0x00, 0x00,
                              0x00, 0x00, 0x00, 0x00,
                              0x00, 0x00, 0x00, 0x00,
                              0x00, 0x00, 0x00, 0x00 };

/* Select IPv6 address mode.
 * 0: disable IPv6.
 * 1: use static address above, no autoconfig.
 * 2: enable autoconfiguration. This will overwrite the static address
 *    above as soon as a route announcement is received. */
uint8_t EEPROM ee_ipv6addrmode = 2;

/* Select timezone. Set this to the number of seconds (!) to add to or
 * substract from UTC / GMT.
 * for example, for Central European Time (CET), which is UTC +1 hour, set
 * this to 3600. */
int32_t EEPROM ee_timezone = 1 * 3600;

/* Handle daylight saving time (DST) / summer time?
 * Note: This needs information about when DST starts and ends in
 * timeconvert.c. The default values there only cover Europe and need
 * to be adapted for this to work in other parts of the world! */
uint8_t EEPROM ee_handledst = 1;

/* Display brightness (for the LED module - valid values 0 - 7) */
uint8_t EEPROM ee_ledbri = 3;

/* This password is needed to send commands over ethernet.
 */
uint8_t EEPROM ee_rconpass[16] = "FICKEN32";

