/* $Id: ledmodule.h,v 1.3 2012-03-10 13:08:12 simimeie Exp $
 * Functions for communicating with the LED module.
 * The module is connected through an i2c bus, it consists of three SAA 1064
 * driver ics.
 */

#ifndef _LEDMODULE_H_ 
#define _LEDMODULE_H_

#ifdef LEDMODULE

extern uint8_t led_brightness;   /* Brightness setting for the LEDs (0-7) */
extern uint8_t led_dispovon;   /* display override activation */
extern uint8_t led_dispovbytes[6]; /* the byte values sent to the LED display
                                    * for the display override */
extern uint16_t led_dispovendticks;  /* at which tick counter we stop */

/* Initialize the LED module... This basically enables the pullups on the I2C
 * Bus pins */
void led_init(void);

/* Configures the brightness of the LED module, or rather: the current the
 * driver allows through them. Value is taken from the var. led_brightness.
 * The values 0 through 7 can be used, corresponding to 0 through 21 mA */
void led_set_brightness(void);

/* This sets one digit on the LED module.
 * digit   is the number of the digit (0 - 7)
 * val     is a bitfield that contains the values to set. See the leddigits
 *         array for useful values for this. */
void led_set_digit(uint8_t digit, uint8_t val);

/* returns an entry from the LED font. Has
 * * numbers 0-f in 0x00-0x09 and '0'-'9','a'-'f' and
 * * some special chars (. -)
 */
uint8_t led_getfontentry(uint8_t c);

/* Maps logical display position 0-5 (or 0-7)
 * to the proper address for use with the led_* functions.
 * This naturally has to be adapted to the hardware wiring. */
uint8_t led_map(uint8_t n);

#else /* ndef LEDMODULE */

#define led_set_digit(d, v) if (0) { }
#define led_set_brightness() if (0) { }
#define led_init() if (0) { }
#define led_getfontentry(c) 0
#define led_map(c) 0

#endif /* ndef LEDMODULE */

#endif
